function [EPH,E1,E2] = ephemeris(id,t,source_file)

  % eph=ephemeris( int id, int t, string 'source_file')
  %
  % spchal Lubo Tlskal
  %
  % PURPOSE    :  VYHLEDA EFEMERIDY NEJBLIZSI ZADANEMU CASU
  %               V PRISLUSNEM SOUBORU FORMATU RINEX
  %               
  %
  % PARAMETERS :
  %         IN :  ephemeris: ( int id,int t,string source_file)
  %                          id (E.G. 10)                  
  %                          t  (E.G. 49244 CAS V SEC OD PULNOCI)        
  %                          source_file(E.G. GOPE0810[1].txt)                      
  %        OUT :  EPH(8,4)                    
  %--------------------------------------------------------------------
  %    EPH (i,:)
  
  % i
  
  % 1    PRN            ROK         MESIC           DEN   
  
  % 2    t_0[s]        delta_c      1d_delta_c      2d_delta_c
  
  % 3   IODE            Crs         delta_n         Mo        
  
  % 4   Cuc             e           Cus             sqrt(a)
  
  % 5   TOE             Cic         lo              Cis
    
  % 6   io              Crc         omega0          OMEGA
  
  % 7   di              ?           ?               ?
  
  % 8   ?               ?           ?               ?
  
  %  radek 1 a 2 je upravene ostatni jsou schodne s formatem RINEX
  %
  %
  %--------------------------------------------------------------------- 

p = '  ';
prn = int2str(id);
if(size(prn)==[1 1])
    p(2)=prn;
    prn = p;
end
 
prn_status = 0;
DATA = zeros(7,4);
eof_status=0;
eoh_status =0;
time_test = 24*3600;


fid = fopen(source_file);
while(eof_status==0)
    
    line = fgets(fid);
    
    if(eoh_status ==0)
        eoh_status = strcmp(line(61:73),'END OF HEADER');
    end
    
    if(eoh_status ==1)
        
        prn_status = strcmp(line(1:2),prn);
        
        if(prn_status ==1)
            dat_test = sscanf(line,'%f')';
            t_0 = dat_test(5)*3600+dat_test(6)*60+dat_test(7);
            
            if(time_test >= (abs(t-t_0)))
                dat = dat_test(1:4);
                time = [t_0,dat_test(8:10)];
                time_test = abs(t-t_0);
           
                for i = 1:7
                    line = fgets(fid);
                    DATA(i,:)= sscanf(line,'%f')';
                end
            end    
        end
    end    

eof_status=feof(fid);
end

fclose(fid);

EPH = [dat;time;DATA];

%RSC
% E1 - puvodni prvni radek
% E2 - puvodni zbytek efemerid
cislo = EPH(2,1)/3600;
HMS = [  fix(cislo)   abs(fix(60*cislo-60*fix(cislo)))   abs(3600*cislo-60*fix(60*cislo))  ];
E1 = [EPH(1,:)  HMS EPH(2,2:4)];
E2 = EPH(3:9,:);