function radial = radialt(location,t,EF)
%
%radiln rychlost podle Mlokina (Lubos Tlskal)
%
%radial = radialt(location,t,EF)
%
%location = [FI (rad) LAM (rad) H (m)]
%t = cas pro kter se to poct
%EF = (efemeridy_t1) = ephemeris(PRN,t1,source_file)
%


%-----------------------------------------------------------------------------------
%konstanty

omega_e = 7292115.1467E-11; %s-1
GM      = 398.6005E12;       %m3s-2
%-----------------------------------------------------------------------------------
%nacteni aktualnich efemerid


%-----------------------------------------------------------------------------------
%efemeridy
datum = [EF(1,3),EF(1,4)];
dt = EF(2,2);
ddt =EF(2,3);
dddt= EF(2,4);
Mo = EF(3,4);
sqrt_a = EF(4,4);
to = EF(2,1);
dn =  EF(3,3);
Lo =EF(5,3);
omega_0 = EF(6,3);
io = EF(6,1);
TOE = EF(5,1);
Cuc = EF(4,1);
Cus = EF(4,3);
Crc = EF(6,2);
Crs = EF(3,2);
Cic = EF(5,2);
Cis = EF(5,4);
OMEGA =EF(6,4);
e = EF(4,2);
di = EF(7,1);
io= EF(6,1);

%oprava hodin druzice
Cclock =dt+ddt*(t-to)+dddt*(t-to)^2; 

%Stredni anomalie M
M = Mo+(sqrt(GM)/sqrt_a^3+dn)*(t-to);

%delka L vystupneho uzlu  v terestrickem systemu  (uhel rotace okolo z)
L = Lo+(OMEGA-omega_e)*(t-to)-omega_e*TOE;
%Excentricka anomalie E

Eold = M;
for i = 1:10
    E = M+e*sin(Eold);
    E-Eold;
    Eold=E;
end

%prava anomalie uhel , ktery svira pruvodic se smerem do perigea
v =2*atan2(sqrt(1+e)*tan(E/2),sqrt(1-e));
%argument sirky
u = v+omega_0+Cuc*cos(2*v+2*omega_0)+Cus*sin(2*v+2*omega_0);
% uhlova rychlost rotace
omega = omega_0+Cuc*cos(2*u)+Cus*sin(2*u);
%sklon roviny drahy
i = io + Cic*cos(2*u)+Cis*sin(2*u)+di*(t-to);
%delka pruvodice
r = sqrt_a^2*(1-e*cos(E))+Crc*cos(2*u)+Crs*sin(2*u);
%vektor pruvodice v rovine drahy
vec_r =[r*cos(v);r*sin(v);0];
dvec_r = sqrt(GM/(sqrt_a^2*(1-e^2)))*[-sin(v);cos(v)+e;0];
%vektor pruvodice v rovnikove soustave
vec_ro = rz(-OMEGA)*rx(-i)*rz(-omega)*vec_r; 
dvec_ro = rz(-OMEGA)*rx(-i)*rz(-omega)*dvec_r;

%vektor pruvodice a rychlosti v soustave spojene se zemi (WGS84)

RO = rz(-L)*rx(-i)*rz(-omega)*vec_r;

%------------------------------------------------------------------------------------
%souradnice pozorovatele ve WGS84
FI = location(1);
LAM = location(2);
H = location(3);

e2  = 0.006694379990141;
a = 6378137;
N = a/ sqrt( 1-e2*sin(FI)^2 );

x = (N+H)*cos(FI)*cos(LAM);
y = (N+H)*cos(FI)*sin(LAM);
z = (N*(1-e2)+H)*sin(FI);
%vektor pozorovatele ve WGS84
rop = [x; y; z];
%-----------------------------------------------------------------------------------


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
%radialni rychlost
%to je snad ta spravna derivace
dRO = omega_e*drz(-L)*rx(-i)*rz(-omega)*vec_r+rz(-L)*rx(-i)*rz(-omega)*dvec_r;

ropd = RO-rop;

%radialni rychlost

norma = ropd'*ropd;
norma = sqrt(norma);


radial = (ropd'*dRO  )/norma;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%